%global _hardened_build 1

# Make reproducible builds possible
%global source_date_epoch_from_changelog 0
%global clamp_mtime_to_source_date_epoch 1
%global use_source_date_epoch_as_buildtime 1
%define _buildhost apkg

%{!?_syprefix: %define _syprefix /opt/symas }
%{!?_etcfix: %define _etcfix %{_syprefix}/etc }
%{!?_sylibdir: %define _sylibdir %{_syprefix}/lib }
%{!?_varfix: %define _varfix /var/symas }

%if 0%{?suse_version}
# We don't seem to have %{dist} in SUSEs, define our own
%{!?dist: %define dist .sles15 }
%endif

Summary: Symas's Cyrus-SASL build
Name: symas-cyrus-sasl
Version: 2.1.28+20230721
Release: 1%{?dist}
License: MIT
Source: %{name}-v%{version}.tar.xz

URL: https://cyrusimap.org/
VCS: https://git.symas.net/symas-public/cyrus-sasl.git

# Apparently distro setup should fill this in, but can't see where,
# Fake ours from dist and strip the leading dot
Distribution: %(echo %{?dist} | tr -d .)

AutoReqProv: no
# BuildRequires one at a time, microdnf doesn't support comma separated dependencies
BuildRequires: symas-buildtools >= 1.0.4
BuildRequires: gcc
BuildRequires: make
BuildRequires: automake
BuildRequires: libtool
BuildRequires: autoconf
BuildRequires: symas-heimdal-devel
BuildRequires: symas-openssl-devel >= 3.0.0
Requires: symas-cyrus-sasl-libs = %{version}-%{release}
Requires: symas-openssl-libs >= 3.0.0
Requires: symas-heimdal-libs >= 7.8.0-3

Patch0: 0001-Make-the-libsasl2-symbols-versioned.patch

%description
The Symas Cyrus-SASL build

%prep
%setup -qn %{name}-v%{version}
%patch0 -p1

%build
aclocal --install;
autoreconf --verbose --force --install -Wno-portability;
sed -i.bak 's/-lRSAglue //' configure

%if 0%{?suse_version}
LDFLAGS="-L%{_sylibdir} -Wl,-rpath,%{_sylibdir}" \
%else
LDFLAGS="%{__global_ldflags} -L%{_sylibdir} -Wl,-rpath,%{_sylibdir}" \
%endif
CFLAGS="%{optflags} -D_REENTRANT -DGETXXNAM_R_5ARG" \
CXXFLAGS="%{optflags} -D_REENTRANT" \
CPPFLAGS=-I%{_syprefix}/include \
./configure --prefix=%{_syprefix} \
	--with-datadir=%{_varfix} \
	--with-saslauthd=%{_varix}/sasl \
	--localstatedir=%{_varfix} \
	--sharedstatedir=%{_etcfix} \
	--sysconfdir=%{_etcfix} \
	--with-plugindir=%{_sylibdir}/sasl2 \
	--with-dblib=no \
	--with-sqlite=no \
	--with-des=no \
	--with-devrandom=/dev/urandom \
	--with-gss_impl=heimdal \
	--with-lib-subdir=lib \
	--with-openssl=%{_syprefix} \
	--enable-gssapi=%{_syprefix} \
	--enable-login \
	--enable-shared=yes --enable-static=no --without-python
make

%install
make install DESTDIR=%{buildroot}
rm -rf %{buildroot}%{_syprefix}/sbin
rm -rf %{buildroot}%{_syprefix}/share/man/man8
rm -rf %{buildroot}%{_sylibdir}/*.la
mkdir -p %{buildroot}%{_syprefix}/share/doc/cyrus-sasl
install -m 0644 COPYING %{buildroot}%{_syprefix}/share/doc/cyrus-sasl
install -m 0644 README %{buildroot}%{_syprefix}/share/doc/cyrus-sasl

%package libs
Summary: Cyrus-SASL Libaries
AutoReqProv: no
Requires: symas-openssl-libs >= 3.0.0, symas-heimdal-libs >= 7.8.0-3

%description libs
The symas-cyrus-sasl-libs package contains the curl libraries

%package devel
Summary: Cyrus-SASL Development
AutoReqProv: no
Requires: symas-cyrus-sasl-libs = %{version}-%{release}

%description devel
The symas-cyrus-sasl-devel package contains the linking libraries and include files

%files libs
%defattr(-,root,root)
%dir %{_sylibdir}/sasl2
%{_sylibdir}/*.so.*
%{_sylibdir}/sasl2/*
%{_syprefix}/share/doc/cyrus-sasl

%files devel
%defattr(-,root,root)
%{_syprefix}/include
%{_sylibdir}/*.so
%{_sylibdir}/pkgconfig
%{_syprefix}/share/man/man3

%changelog
* Wed Jun 05 2024 Symas Support <support@symas.com> - 2.1.28+20230721-1
- Switch to apkg for packaging
- Disable 3DES
- Version based on 2.1.28
* Wed May 31 2023 Symas Support <support@symas.com> - 2.1.28-5
- Rebuilding with OpenSSL3 support v 2.1.28-5
- Added some patches related to openssl3 RC4
* Thu Jun 30 2022 Symas Support <support@symas.com> - 2.1.28-2
- patch to make libsasl2 symbols versioned
* Tue Jun 28 2022 Symas Support <support@symas.com> - 2.1.28-1
- cyrus-sasl 2.1.28 Release
* Tue Nov 16 2021 Symas Support <support@symas.com> - 2.1.27-4
- Package COPYING and README files
* Mon May 24 2021 Symas Support <support@symas.com> - 2.1.27-3
- Update paths for odd Symas Gold locations
* Tue May 11 2021 Symas Support <support@symas.com> - 2.1.27-2
- FHS fixups
* Tue Apr 6 2021 Symas Support <support@symas.com> - 2.1.27-1
- initial packaging
